from random import randint
import re

import niobot
from niobot import (
    CommandParserError,
    Context,
    Module,
    NioBot,
)


class ChanceModule(Module):
    """Commands that simulate chance (Dice rolls, card selection, etc)."""

    def __init__(self, bot: NioBot):
        self.bot = bot

    @niobot.command()
    async def roll(self, ctx: Context, dice: str):
        """Roll some dice with an optional modifier."""
        valid = re.match(r"(\d+)d(\d+)([\+-/\*]\d+)?", dice)
        if valid is None:
            await ctx.respond("Error: Invalid dice roll notation.")
            raise CommandParserError("Invalid dice roll notation.")
        dice_parts = (int(valid.group(1)), int(valid.group(2)), valid.group(3))

        if not 1 <= dice_parts[0] <= 100:
            await ctx.respond("Error: Can only roll between 1 and 100 dice.")
            raise CommandParserError("Can only roll between 1 and 100 dice.")

        if not 2 <= dice_parts[1] <= 100:
            await ctx.respond("Error: Dice must have between 2 and 100 faces.")
            raise CommandParserError("Dice must have between 2 and 100 faces.")

        rolls: list[int] = []
        for _ in range(dice_parts[0]):
            rolls.append(randint(1, dice_parts[1]))
        total = sum(rolls)

        await ctx.respond(f"{dice}: {total} ({rolls})")

        # await ctx.client.send_message(
        #    ctx.room, f"{dice_parts[0]}, {dice_parts[1]}, {dice_parts[2]}"
        # )
